jacinle.utils.debug
===================

.. automodule:: jacinle.utils.debug

   
   
   

   
   
   

   
   
   .. rubric:: Functions

   .. autosummary::
   
      decorate_exception_hook
      exception_hook
      hook_exception_ipdb
      lf_indent_log
      lf_indent_print
      log_function
      profile
      time
      timeout_ipdb
      unhook_exception_ipdb
   
   

   
   
   











.. rubric:: Functions

.. autofunction:: decorate_exception_hook

.. autofunction:: exception_hook

.. autofunction:: hook_exception_ipdb

.. autofunction:: lf_indent_log

.. autofunction:: lf_indent_print

.. autofunction:: log_function

.. autofunction:: profile

.. autofunction:: time

.. autofunction:: timeout_ipdb

.. autofunction:: unhook_exception_ipdb


